#
# spec file for package openstack-monasca-agent
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sname monasca-agent
%define username            monasca-agent
%define groupname           monasca
%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           openstack-monasca-agent
Version:        2.8.1~dev10
Release:        923.1
Summary:        OpenStack Monasca metrics agent
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://wiki.openstack.org/wiki/Monasca
Source0:        monasca-agent-stable-rocky.tar.gz
Source1:        %{name}-sudoers
Source2:        %{name}.target
Source3:        %{name}.tmpfiles
Source4:        %{name}.polkit
Source5:        %{name}-collector.service
Source6:        %{name}-forwarder.service
Source7:        %{name}-statsd.service
BuildRequires:  fdupes
BuildRequires:  openstack-macros
BuildRequires:  python-PyYAML >= 3.10
BuildRequires:  python-devel
BuildRequires:  python-eventlet >= 0.18.2
BuildRequires:  python-futures >= 3.0.0
BuildRequires:  python-httplib2 >= 0.9.1
BuildRequires:  python-mock
BuildRequires:  python-monasca-common >= 2.7.0
BuildRequires:  python-monascaclient >= 1.7.0
BuildRequires:  python-netaddr >= 0.7.18
BuildRequires:  python-ntplib >= 0.3.2
BuildRequires:  python-os-testr
BuildRequires:  python-oslo.concurrency >= 3.25.0
BuildRequires:  python-oslo.config >= 5.2.0
BuildRequires:  python-oslo.i18n >= 3.15.3
BuildRequires:  python2-oslo.middleware
BuildRequires:  python-oslo.utils >= 3.33.0
BuildRequires:  python-oslo.vmware >= 2.17.0
BuildRequires:  python-oslotest
BuildRequires:  python-psutil >= 3.2.2
BuildRequires:  python-pymongo >= 3.0.2
BuildRequires:  python-python-memcached >= 1.56
BuildRequires:  python-redis >= 2.10.0
BuildRequires:  python-requests >= 2.14.2
BuildRequires:  python-stevedore >= 1.20.0
BuildRequires:  python-testrepository
BuildRequires:  python-tornado >= 4.5.3
BuildRequires:  sudo
Requires:       python-%{sname} = %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
BuildRequires:  systemd
Requires(post): systemd
Requires(postun):   systemd
Requires(preun):    systemd
%endif

%description
The Monasca Agent is a modern Python monitoring agent for gathering metrics and
sending them to the Monasca API.

%package -n python-%{sname}
Summary:        Python module for monasca-agent
Group:          Development/Languages/Python
Requires:       python-PyYAML >= 3.10
Requires:       python-eventlet >= 0.18.2
Requires:       python-futures >= 3.0.0
Requires:       python-httplib2 >= 0.9.1
Requires:       python-keystoneclient >= 3.8.0
Requires:       python-monasca-common >= 2.7.0
Requires:       python-monascaclient >= 1.7.0
Requires:       python-netaddr >= 0.7.18
Requires:       python-neutronclient
Requires:       python-novaclient
Requires:       python-ntplib >= 0.3.2
Requires:       python-oslo.concurrency >= 3.25.0
Requires:       python-oslo.config >= 5.2.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-oslo.vmware >= 2.17.0
Requires:       python-psutil >= 3.2.2
Requires:       python-pymongo >= 3.0.2
Requires:       python-python-memcached >= 1.56
Requires:       python-redis >= 2.10.0
Requires:       python-requests >= 2.14.2
Requires:       python-stevedore >= 1.20.0
# FIXME(jpena): Remove this conditional once python-toml is available in RDO
%if 0%{?rdo}
Requires:       python-tornado >= 4.5.3
%else
Requires:       python-toml
Requires:       python-tornado >= 4.5.3
%endif

%description -n python-%{sname}
The Monasca Agent is a modern Python monitoring agent for gathering metrics and
sending them to the Monasca API.

This package contains monasca-agent Python module.

%prep
%autosetup -n %{sname}-2.8.1.dev10
%py_req_cleanup
# contains various binary files etc that we don't need
rm -rf packaging/monasca-agent{,-deb}

%build
%py2_build

%install
%py2_install

# /etc
install -d -m 755 %{buildroot}%{_sysconfdir}/monasca
install -d -m 750 %{buildroot}%{_sysconfdir}/monasca/agent/conf.d

# /usr/lib
install -d -m 750 %{buildroot}%{_prefix}/lib/monasca/agent/custom_checks.d
install -d -m 750 %{buildroot}%{_prefix}/lib/monasca/agent/custom_detect.d

# /var
install -d -m 750  %{buildroot}%{_localstatedir}/log/%{sname}

# sudoers configuration
install -D -m 440 %{SOURCE1} %{buildroot}%{_sysconfdir}/sudoers.d/%{name}

# systemd unit file
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.target
install -D -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/%{name}-collector.service
install -D -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/%{name}-forwarder.service
install -D -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/%{name}-statsd.service
%if 0%{?suse_version}
mkdir -p %{buildroot}%{_sbindir}
ln -sr %{buildroot}%{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%endif

# systemd tmpfile
install -D -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/openstack-monasca-agent.conf

# polkit permissions
install -D -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/polkit-1/rules.d/49-monasca-agent.rules

%fdupes %{buildroot}%{python2_sitelib}

%pre
# create user and groups
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/openstack-monasca-agent.conf
%systemd_post %{name}.target
%systemd_post %{name}-collector.service
%systemd_post %{name}-forwarder.service
%systemd_post %{name}-statsd.service

%preun
%systemd_preun %{name}.target
%systemd_preun %{name}-collector.service
%systemd_preun %{name}-forwarder.service
%systemd_preun %{name}-statsd.service

%postun
%systemd_postun %{name}.target
%systemd_postun %{name}-collector.service
%systemd_postun %{name}-forwarder.service
%systemd_postun %{name}-statsd.service

%check
find . -type f -name *.pyc -delete
find . -type f -name '*test_service_plugin.py' -delete
python setup.py test

%files
%dir %attr(-, root, monasca) %{_sysconfdir}/monasca
%dir %attr(0750, %{username}, %{groupname}) %{_sysconfdir}/monasca/agent
%dir %attr(0750, %{username}, %{groupname}) %{_sysconfdir}/monasca/agent/conf.d
%_tmpfilesdir/openstack-monasca-agent.conf
%config %{_sysconfdir}/monasca/agent
%config %{_sysconfdir}/sudoers.d/%{name}
%dir %{_prefix}/lib/monasca
%{_prefix}/lib/monasca/agent
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/%{sname}
%{_unitdir}/%{name}.target
%{_unitdir}/%{name}-collector.service
%{_unitdir}/%{name}-forwarder.service
%{_unitdir}/%{name}-statsd.service
%if 0%{?suse_version}
%{_sbindir}/rc%{name}
%endif
%{_sysconfdir}/polkit-1/
%{_sysconfdir}/polkit-1/rules.d/
%{_sysconfdir}/polkit-1/rules.d/49-monasca-agent.rules

%files -n python-%{sname}
%doc README.rst
%license LICENSE
%{_bindir}/monasca-collector
%{_bindir}/monasca-forwarder
%{_bindir}/monasca-setup
%{_bindir}/monasca-statsd
%{python2_sitelib}/monasca_agent
%{python2_sitelib}/monasca_agent-*.egg-info
%{python2_sitelib}/monasca_setup
%dir %{_datadir}/monasca
%{_datadir}/monasca/agent

%changelog
* Sat Mar 30 2019 cloud-devel@suse.de
- update to version 2.8.1~dev10
  - monasca-setup  httpcheck args plugin: keystone_config
* Thu Mar 21 2019 cloud-devel@suse.de
- update to version 2.8.1~dev9
  - Update OVS detection plugin for Keystone v3
* Tue Feb 19 2019 cloud-devel@suse.de
- update to version 2.8.1~dev8
  - properly convey Keystone v3 params
* Fri Jan 25 2019 cloud-devel@suse.de
- update to version 2.8.1~dev7
  - enable Keystone v3 support for http_check detection plugin
* Sat Dec 29 2018 cloud-devel@suse.de
- update to version 2.8.1~dev6
  - Improve metric error handling
* Tue Nov 13 2018 johannes.grassler@suse.com
- Fix service name references in service files (bsc#1115473)
* Thu Nov  8 2018 johannes.grassler@suse.com
- Remove 614284-fix-urllib-references.patch (merged upstream)
* Thu Nov  8 2018 cloud-devel@suse.de
- update to version 2.8.1~dev5
  - Fix urllib references
* Mon Nov  5 2018 johannes.grassler@suse.com
- Add 614284-fix-urllib-references.patch
* Mon Nov  5 2018 johannes.grassler@suse.com
- Switch to systemd driven supervision
* Thu Oct 11 2018 dmueller@suse.com
- add fdupes call
* Tue Sep 18 2018 cloud-devel@suse.de
- update to version 2.8.1~dev4
  - Revert refresh_token method
  - Fix log rotation in monasca agent
  - Use a newer hacking (1.0.x)
  - Update supervisor version lower bound
  - Add container memory percentage metric when running in k8s
  - Add support for k8s StatefulSet
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Make forwarder and collector compatible with py35
  - Fix RabbitMQ whitelist documentation error
  - Add working set memory and job dimension to k8s/cadvisor  plugin
  - Trivial fix typo of description
  - Remove -U from pip install
  - Add annotation for not adding kubernetes labels
  - libvirt check: use unqualified hostname
  - added .stestr in gitignore
  - Don't drop batch on one bad metric
  - Remove PostgreSQL tempest jobs from Zuul
  - Manual updated from global requirements
  - Update docstrings
  - Update k8s utils and prometheus plugin
  - Add some new metrics and update some old ones
  - Add Apache License
  - Zuul: Remove project name
  - Ceph monitoring plugin: allow using sudo
  - Update from global requirements
  - Add max batch size for writing to API
  - Trivial: Update pypi url to new url
  - Replace basestring with six.string_types
  - Add LXC swap metric collector and fix lxc bug
  - uncap eventlet
  - Add owner type dimension so we can key off of it in alarming
  - Add Cloudkitty detection plugin (Cloudkitty - Rating Service)
  - Fix error logs in prometheus w/o prometheus annotations.
  - fix tox python3 overrides
  - Fix Kibana plugin config duplication
  - Updated from global requirements
  - Add prerequisite for enabling all untunable metrics
  - Update old python string format
  - Add option for metric type annotation
  - Use six library to import python queue
  - Fix hostname matching in kubernetes_api plugin
  - Avoid overwriting sys.path "ip" command
  (removes 0001-Avoid-overwriting-sys.path-ip-command.patch)
  - Fix the example http_check.yaml for Keystone
  - import zuul job settings from project-config
  - Fix ca_file and insecure usage
  - Update pep8 checks
  - Python3: Make monasca-setup compatible with py35
  - Removed dependency on supervisor
  - readd nsfs to the list of ignored filesystems
  - Add a smaller vcenter plugin for status
  - Enable the process plugin in Docker environment
  - Introduce agent plugin for LXC
  - Update links in README
  - Manual update from global requirements
  - Add network congestion detection to monasca
  - Use monasca-common to validate metrics
  - Change template/example of Libvirt config file
  - [Trivialfix]Modify a grammatical error
  - Add monasca agent plugin to monitor cassandra health
  (removes monitor-cassandra-538096.patch)
  - Add .zuul.yaml file
  - Fix type error in monasca agent
  - added license comments
  - Add new metrics for Cadvisor plugin
  - Adding httpd-worker apache process on SLES
  - Update congestion agent plugin
  - Fix sample for ZooKeeper plugin
  - Remove license section from README.md
  - Avoid tox_install.sh for constraints support
  - Fix Prometheus metrics endpoint scanning
  - added virtenv in gitignore
  - Added aggregate VM counts to livbirt check
  (removes libvirt-aggregate-status.patch)
  - Rework getting limits and requests for containers
  - Update .gitreview for stable/rocky
  - Correctly detects apache process when mod_perl is installed
  - Remove deprecated io_loop argument
  - Convert README to reStructuredText
  - change assert(Not)Equals to assert(Not)Equal
  - Configure Keystone with detection_args for http_check detection plugin
  - fix misspelling of 'monasca'
  - Fix slash handling in KubernetesConnector's get_request
  - Allow Keystone config in init_config for http check
  - Fix one error message in prometheus
  - Fix libvirt plugin to handle FQDN of compute node
  - Update documentation
  - Fix auto-detect crash on monasca-setup when using oslo.config
  - Check interfaces KeyError for network data
  - Correct detection status in congestion plugin
* Thu Aug 30 2018 cloud-devel@suse.de
- update to version 2.2.5~dev1
  - import zuul job settings from project-config
* Wed May 16 2018 cloud-devel@suse.de
- update to version 2.2.4~dev3
  - Correctly detects apache process when mod_perl is installed (bsc#1089952)
* Sat Apr 28 2018 cloud-devel@suse.de
- update to version 2.2.4~dev2
  - Allow Keystone config in init_config for http check
* Fri Apr 13 2018 cloud-devel@suse.de
- update to version 2.2.4~dev1
  - Add prerequisite for enabling all untunable metrics
* Tue Mar 27 2018 cloud-devel@suse.de
- update to version 2.2.3~dev2
  - Fix libvirt plugin to handle FQDN of compute node
* Sat Mar 24 2018 cloud-devel@suse.de
- update to version 2.2.3~dev1
  - Update supervisor version lower bound
* Fri Feb 23 2018 dmueller@suse.com
- add 0001-Avoid-overwriting-sys.path-ip-command.patch (bsc#1082403)
* Fri Feb  2 2018 johannes.grassler@suse.com
- Add monitor-cassandra-538096.patch
- Update to latest rpm-packaging spec
* Sat Jan 27 2018 cloud-devel@suse.de
- update to version 2.2.2~dev2
  - Revert refresh_token method
* Wed Jan 24 2018 cloud-devel@suse.de
- update to version 2.2.2~dev1
  - Fix monasca-forwarder never able to start
* Thu Jan 18 2018 johannes.grassler@suse.com
- Update to current rpm-packaging spec and add
  libvirt-aggregate-status.patch (added in rpm-packaging)
* Tue Jan 16 2018 cloud-devel@suse.de
- update to version 2.2.1~dev10
  - Fix ca_file and insecure usage
  - Update docstrings
* Wed Jan 10 2018 cloud-devel@suse.de
- update to version 2.2.1~dev7
  - Fix auto-detect crash on monasca-setup when using oslo.config
* Tue Jan  2 2018 cloud-devel@suse.de
- update to version 2.2.1~dev6
  - Adding httpd-worker apache process on SLES
* Thu Dec  7 2017 cloud-devel@suse.de
- update to version 2.2.1~dev5
  - Fix Kibana plugin config duplication
* Tue Nov 28 2017 cloud-devel@suse.de
- update to version 2.2.1~dev4
  - libvirt check: use unqualified hostname
* Fri Oct 20 2017 cloud-devel@suse.de
- update to version 2.2.1~dev3
  - Ceph monitoring plugin: allow using sudo
* Mon Aug 28 2017 cloud-devel@suse.de
- update to version 2.2.1~dev2
* Thu Jul 27 2017 cloud-devel@suse.de
- update to version 1.9.2~dev3
* Fri Jul 14 2017 cloud-devel@suse.de
- update to version 1.9.1~dev11
* Mon Jun 26 2017 cloud-devel@suse.de
- update to version 1.9.1~dev10
* Fri Apr 21 2017 cloud-devel@suse.de
- update to version 1.9.1~dev1
* Fri Apr 21 2017 cloud-devel@suse.de
- update to version 1.8.1~dev8
* Mon Apr 10 2017 cloud-devel@suse.de
- update to version 1.8.1~dev5
* Wed Mar 29 2017 tbechtold@suse.com
- Initial packaging (version 1.8.0)
